"use strict";
// Copyright 2018 Knowledge Expert SA
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
Object.defineProperty(exports, "__esModule", { value: true });
exports.SlicedWebElementsLocator = void 0;
class SlicedWebElementsLocator {
    /**
     * Locates a slice in original collection webelements.
     * @param start The inclusive "start" index of webelements to be sliced.
     * @param end The exclusive "end" index of webelements to be sliced.
     * @param collection Original collection to be sliced.
     */
    constructor(start, end, step, collection) {
        this.start = start;
        this.end = end;
        this.step = step;
        this.collection = collection;
        this.start = start;
        this.end = end;
        this.step = step;
        this.collection = collection;
    }
    async find() {
        // TODO: consider using https://www.npmjs.com/package/slice
        const webelements = (await this.collection.getWebElements());
        const sliced = webelements.slice(this.start, this.end);
        const toBeFiltered = this.step > 0 ? sliced : sliced.reverse();
        const step = this.step < 0 ? -this.step : this.step;
        return toBeFiltered.reduce((acc, element, i) => (i % step === 0
            ? [...acc, element]
            : acc), []);
    }
    toString() {
        var _a, _b;
        return `${this.collection.toString()}[${this.start ? this.start.toString() : ''}:${this.end ? this.end.toString() : ''}${((_a = this.step) === null || _a === void 0 ? void 0 : _a.toString()) === '1' ? '' : `:${(_b = this.step) === null || _b === void 0 ? void 0 : _b.toString()}`}]`;
    }
}
exports.SlicedWebElementsLocator = SlicedWebElementsLocator;
//# sourceMappingURL=slicedWebElementsLocator.js.map